@@ -1,6 +1,4 @@
-"""**plotly\_resampler**: visualizing large sequences
-
-"""
+"""**plotly\_resampler**: visualizing large sequences."""
 
 from .aggregation import (
     LTTB,
@@ -9,15 +7,16 @@ from .aggregation import (
     FuncAggregator,
     MinMaxOverlapAggregator,
 )
-from .figure_resampler import FigureResampler
+from .figure_resampler import FigureResampler, FigureWidgetResampler
 
 __docformat__ = "numpy"
 __author__ = "Jonas Van Der Donckt, Jeroen Van Der Donckt, Emiel Deprost"
-__version__ = "0.5.0"
+__version__ = "0.6.2"
 
 __all__ = [
     "__version__",
     "FigureResampler",
+    "FigureWidgetResampler",
     "EfficientLTTB",
     "MinMaxOverlapAggregator",
     "LTTB",
